package com.yunzhi.nanyang.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.nanyang.common.BaseController;
import com.yunzhi.nanyang.common.Constants;
import com.yunzhi.nanyang.common.ResponseBean;
import com.yunzhi.nanyang.common.StringUtils;
import com.yunzhi.nanyang.entity.SysRole;
import com.yunzhi.nanyang.entity.SysUser;
import com.yunzhi.nanyang.service.ISysRoleService;
import com.yunzhi.nanyang.service.ISysUserService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.yunzhi.nanyang.service.ISysUserRoleService;
import com.yunzhi.nanyang.entity.SysUserRole;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * <p>
    * 用户角色 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2022-03-07
 */

@Api(tags = "用户角色")
@RestController
@RequestMapping("/")
public class SysUserRoleController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(SysUserRoleController.class);

    @Autowired
    public ISysUserRoleService iSysUserRoleService;

    @Autowired
    public ISysUserService iSysUserService;

    @Autowired
    public ISysRoleService iSysRoleService;

    /**
     * 分页查询列表
     * @param userId
     * @return
     */
    @RequestMapping(value="/admin/user-role",method= RequestMethod.GET)
    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
    @RequiresPermissions("role:view,user:view")
    public ResponseBean sysUserRoleList(@ApiParam("用户ID") @RequestParam(value ="user_id") String userId) throws Exception{

        QueryWrapper<SysUserRole> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("user_id", userId);
        queryWrapper.orderByDesc("role_id");

        List<SysUserRole> result = iSysUserRoleService.list(queryWrapper);
        return ResponseBean.success(result);
    }

    /**
     * 保存对象
     * @param sysUserRole 实体对象
     * @return
     */
    @RequestMapping(value="/admin/user-role",method= RequestMethod.POST)
    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
    @RequiresPermissions("user:add")
    public ResponseBean sysUserRoleAdd(@ApiParam("保存内容") @RequestBody SysUserRole sysUserRole) throws Exception{

        String userId = sysUserRole.getUserId();
        String roleId = sysUserRole.getRoleId();

        if (StringUtils.isEmpty(roleId) || StringUtils.isEmpty(userId)) {
            return ResponseBean.error("用户或者角色不能为空");
        }

        if (userId.equals(Constants.ADMIN_ID)) {
            return ResponseBean.error("无权进行当前操作");
        }

        SysUser sysUser = iSysUserService.getExistBy("user_id", userId, false,true);
        if (sysUser == null) {
            return ResponseBean.error("用户不存在");
        }

        SysRole sysRole = iSysRoleService.getById(roleId);
        if (sysRole == null) {
            return ResponseBean.error("角色不存在");
        }

        boolean canAccess = iSysUserService.canAccessData(userId, currentUser().getUserId());
        if (!canAccess) {
            return ResponseBean.error("无权进行当前操作");
        }

        SysUserRole origin = iSysUserRoleService.checkExist(sysUserRole.getRoleId(), userId);
        if (origin != null) {
            return ResponseBean.success(origin);
        }

        sysUserRole.setSerialNo(null);
        if (iSysUserRoleService.save(sysUserRole)){
            return ResponseBean.success(sysUserRole);
        }else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @RequestMapping(value="/admin/user-role/{id}", method= RequestMethod.DELETE)
    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
    @RequiresPermissions("user:delete")
    public ResponseBean sysUserRoleDelete(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
        SysUserRole sysUserRole = iSysUserRoleService.getById(id);
        if (null == sysUserRole) {
            return ResponseBean.success("success");
        }

        String userId = sysUserRole.getUserId();
        SysUser sysUser = iSysUserService.getExistBy("user_id", userId, false,true);
        if (sysUser == null) {
            return ResponseBean.error("用户不存在");
        }

        boolean canAccess = iSysUserService.canAccessData(userId, currentUser().getUserId());
        if (!canAccess) {
            return ResponseBean.error("无权进行当前操作");
        }

        if(iSysUserRoleService.removeById(id)){
            return ResponseBean.success("success");
        }else {
            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

}
